@@ -1,10 +1,13 @@
-use webview_app::{app::App, app::AppSettings};
+use webview_app::{app::App, app::{AppSettings, WarpSettings}};
 
 fn run_app() {
     let app = App::new(
         AppSettings { 
             title: "Rust Web View 👍".to_string(),
-            warp_port: 9999,
+            warp_settings: Some(WarpSettings { 
+                port: 9999,
+                init_fn: None,
+            }),
             enable_dev_tools: true,
             ..Default::default()
         }
