@@ -2,6 +2,10 @@
 //! and run an application containing only a webview.
 use std::{env, net::SocketAddr, path::PathBuf};
 
+#[cfg(target_os = "linux")]
+use gtk::{Application, ApplicationWindow, Builder};
+#[cfg(target_os = "linux")]
+use webkit2gtk::{WebView, WebViewExt};
 use tokio::runtime::Runtime;
 
 #[cfg(target_os = "linux")]
@@ -10,6 +14,9 @@ use crate::warp_server::start;
 #[cfg(target_os = "windows")]
 use crate::windows::app::App as AppImpl;
 
+#[cfg(target_os = "linux")]
+const WEBMSG: &str = "!!webmesg!!";
+
 /// Configuration Settings for the internal warp server.
 ///
 /// Here you have to define the port the warp server is using. You also have the possibility to add filter routes
@@ -142,6 +149,18 @@ pub struct AppSettings {
     pub enable_dev_tools: bool,
     /// If set, then window size is automatically saved to a folder with relative path set to "window_pos_storage_path"
     pub window_pos_storage_path: Option<String>,
+
+    // TODO: Windows
+
+    /// If you want to initialize your application or main window, set this callback. It is lso needed to inject a
+    /// callback if you want to receive msgs from javascript.
+    ///
+    /// This option is only available on linux
+    #[cfg(target_os = "linux")]
+    pub on_app_init: Option<fn(application: &Application, window: & ApplicationWindow, builder: &Option<Builder>, webview: & WebView)>,
+
+    //pub on_msg: Option<fn(application: &Application, window: &)
+
     /// When set to true, you can configure the main window with a glade xml file. This feature is only
     /// available on windows. It is primarily useful for integrating a header bar to the main window.
     /// The glade file has to be named "main.glade", and it has to be placed in the root directory.
@@ -249,7 +268,8 @@ impl Clone for AppSettings {
             warp_settings: self.warp_settings.clone(),
             use_glade: self.use_glade,
             webroot: self.webroot.clone(),
-            window_pos_storage_path: self.window_pos_storage_path.clone()
+            window_pos_storage_path: self.window_pos_storage_path.clone(),
+            on_app_init: self.on_app_init
         }
     }
 }
@@ -267,7 +287,8 @@ impl Default for AppSettings {
             use_glade: false,
             warp_settings: None,
             enable_dev_tools: false,
-            webroot: "".to_string()
+            webroot: "".to_string(),
+            on_app_init: None
         }   
     }
 }
@@ -334,3 +355,22 @@ impl App {
     }
 }
 
+/// If you want callback from javascript, you can call this method in the "on_app_init" callback.
+/// You can then call ```sendMessageToWebView("cmd", "payload")``` 
+///
+/// This option is only available on linux
+#[cfg(target_os = "linux")]
+pub fn connect_msg_callback<F: Fn(&str, &str)->() + 'static>(webview: &WebView, on_msg: F) {
+    webview.connect_script_dialog(move|_, dialog | {
+        let str = dialog.get_message();
+        if str.starts_with(WEBMSG) {
+            let msg = &str[WEBMSG.len()..];
+            if let Some(pos) = msg.find("!!") {
+                let cmd = &msg[0..pos];
+                let payload = &msg[pos+2..];
+                on_msg(cmd, payload);
+            }
+        }
+        true
+    });
+}
\ No newline at end of file
